Module buffer
libdd_
trace_
utils
2.0.2
Module buffer
Module Items
Structs
Functions
In libdd_
trace_
utils::
msgpack_
decoder::
decode
libdd_trace_utils
::
msgpack_decoder
::
decode
Module
buffer
Structs

Buffer
Internal Buffer used to wrap msgpack data for decoding. Provides a couple accessors to extract data from the buffer.
Functions

read_
string_
ref_
nomut
Read a string from
buf
.