pub enum DecodeError {
InvalidConversion(String),
InvalidType(String),
InvalidFormat(String),
IOError,
Utf8Error(String),
}Expand description
Represent error that can happen while decoding msgpack.
Variants
InvalidConversion(String)
Failed to convert a number to the expected type.
InvalidType(String)
Payload does not match the expected type for a trace payload.
InvalidFormat(String)
Payload is not a valid msgpack object.
IOError
Failed to read the buffer.
Utf8Error(String)
The payload contains non-utf8 strings.