read_map_vec

Function read_map_vec 

pub fn read_map_vec<K, V, F, B>(
    len: usize,
    buf: &mut B,
    read_pair: F,
) -> Result<VecMap<K, V>, DecodeError>
Reads a map from the buffer and returns it as a VecMap<K, V>.

Like read_map but returns pairs in a VecMap instead of HashMap for better cache locality when iteration order doesn’t matter.