Module string

Module string 

Functions

handle_null_marker
Handle the null value by peeking if the next value is a null marker, and will only advance the buffer if it is null. If it is not null, you can continue to decode as expected.
read_nullable_str_map_to_strings
Read a nullable hashmap of (string, string) from the slices buf.
read_nullable_string
Read a nullable string from the slices buf.
read_str_map_to_strings
Read a hashmap of (string, string) from the slices buf.