Module v1

Module v1 

Functions

from_buffer
Generic over the deserialization mode (owned BytesData or borrowed SliceData).
from_bytes
Decodes a V1 msgpack payload from owned bytes into a TracerPayloadBytes.
from_slice
Decodes a V1 msgpack payload from a borrowed slice into a TracerPayloadSlice. The resulting payload borrows from the input buffer (same lifetime).