Module v04

Module v04 

Functions

to_len
Computes the number of bytes required to encode the given traces.
to_vec
Serializes traces into a vector of bytes with a default capacity of 0.
to_vec_with_capacity
Serializes traces into a vector of bytes with specified capacity.
write_to_slice
Encodes a collection of traces into a slice of bytes.