Module v1

Module v1 

Functions

to_encoded_byte_len_from_v04
Returns the number of bytes the V1 payload for traces would occupy.
to_encoded_byte_len_from_v1
Computes the number of bytes required to encode the given TracerPayload.
to_vec_from_v04
Serializes traces into a Vec<u8> using the V1 msgpack format.
to_vec_from_v1
Serializes a TracerPayload into a vector of bytes with a default capacity of 0.
to_vec_with_capacity_from_v04
Serializes traces into a Vec<u8> with a pre-allocated capacity.
to_vec_with_capacity_from_v1
Serializes a TracerPayload into a vector of bytes with specified capacity.
write_to_slice_from_v04
Serializes traces into a slice using the V1 msgpack format.
write_to_slice_from_v1
Encodes a TracerPayload into a slice of bytes.