Module send_data

Module send_data 

Modules

send_data_result

Structs

SendData
SendData is a structure that holds the data to be sent to a target endpoint. It includes the payloads to be sent, the size of the data, the target endpoint, headers for the request, and a retry strategy for sending the data.
SendDataBuilder