Module send_with_retry

Module send_with_retry 

Provide send_with_retry utility to send a payload to an Endpoint with retries if the request fails.

Structs

RetryStrategy
Struct representing the retry strategy for sending data.

Enums

RetryBackoffType
Enum representing the type of backoff to use for the delay between retries.
SendWithRetryError
All errors contain the number of attempts after which the final error was returned

Functions

send_with_retry
Send the payload with a POST request to target using the provided retry_strategy if the request fails.

Type Aliases

Attempts
SendWithRetryResult