Span

Struct Span 

pub struct Span<T>
where T: SpanText,
{
Show 15 fields pub service: T, pub name: T, pub resource: T, pub type: T, pub trace_id: u128, pub span_id: u64, pub parent_id: u64, pub start: i64, pub duration: i64, pub error: i32, pub meta: HashMap<T, T>, pub metrics: HashMap<T, f64>, pub meta_struct: HashMap<T, Bytes>, pub span_links: Vec<SpanLink<T>>, pub span_events: Vec<SpanEvent<T>>,
}
The generic representation of a V04 span.

T is the type used to represent strings in the span, it can be either owned (e.g. BytesString) or borrowed (e.g. &str). To define a generic function taking any Span<T> you can use the [SpanValue] trait:

use libdd_trace_utils::span::{Span, SpanText};
fn foo<T: SpanText>(span: Span<T>) {
    let _ = span.meta.get("foo");
}

Fields

service: Tname: Tresource: Ttype: Ttrace_id: u128span_id: u64parent_id: u64start: i64duration: i64error: i32meta: HashMap<T, T>metrics: HashMap<T, f64>meta_struct: HashMap<T, Bytes>span_links: Vec<SpanLink<T>>span_events: Vec<SpanEvent<T>>

Implementations

Source

impl Span<&str>

pub fn try_to_bytes(&self, bytes: &Bytes) -> Option<SpanBytes>

Converts a borrowed SpanSlice into an owned SpanBytes, by resolving all internal references into slices of the provided Bytes buffer. Returns None if any slice is out of bounds or invalid.