pub struct SpanEvent<T>where
T: SpanText,{
pub time_unix_nano: u64,
pub name: T,
pub attributes: HashMap<T, AttributeAnyValue<T>>,
}Expand description
The generic representation of a V04 span event.
T is the type used to represent strings in the span event.
Fields
time_unix_nano: u64name: Tattributes: HashMap<T, AttributeAnyValue<T>>Implementations
Sourceimpl SpanEvent<&str>
impl SpanEvent<&str>
Sourcepub fn try_to_bytes(&self, bytes: &Bytes) -> Option<SpanEventBytes>
pub fn try_to_bytes(&self, bytes: &Bytes) -> Option<SpanEventBytes>
Converts a borrowed SpanEventSlice into an owned SpanEventBytes, resolving references
into the provided Bytes buffer. Fails with None if any slice is invalid or cannot be
converted.