SpanText

Trait SpanText 

pub trait SpanText:
    Debug
    + Eq
    + Hash
    + Borrow<str>
    + Serialize
    + Default {
    // Required method
    fn from_static_str(value: &'static str) -> Self;
}
Trait representing the requirements for a type to be used as a Span “string” type. Note: Borrow is not required by the derived traits, but allows to access HashMap elements from a static str and check if the string is empty.

Required Methods

fn from_static_str(value: &'static str) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl SpanText for &str

Source

fn from_static_str(value: &'static str) -> Self

Source

impl SpanText for BytesString

Source

fn from_static_str(value: &'static str) -> Self

Implementors