TraceData

Trait TraceData 

pub trait TraceData:
    Default
    + Clone
    + Debug
    + PartialEq {
    type Text: SpanText;
    type Bytes: SpanBytes;
}
Trait representing a tuple of (Text, Bytes) types used for different underlying data structures. Note: The functions are internal to the msgpack decoder and should not be used directly: they’re only exposed here due to the unavailability of min_specialization in stable Rust. Also note that the Clone and PartialEq bounds are only present for tests.

Required Associated Types

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors