SpanLinkSlice

Type Alias SpanLinkSlice 

pub type SpanLinkSlice<'a> = SpanLink<&'a str>;

Aliased Type

pub struct SpanLinkSlice<'a> {
    pub trace_id: u64,
    pub trace_id_high: u64,
    pub span_id: u64,
    pub attributes: HashMap<&'a str, &'a str>,
    pub tracestate: &'a str,
    pub flags: u32,
}

Fields

trace_id: u64trace_id_high: u64span_id: u64attributes: HashMap<&'a str, &'a str>tracestate: &'a strflags: u32

Implementations

Source

impl SpanLinkSlice<'_>

pub fn try_to_bytes(&self, bytes: &Bytes) -> Option<SpanLinkBytes>

Converts a borrowed SpanLinkSlice into an owned SpanLinkBytes, using the provided Bytes buffer to resolve all referenced strings. Returns None if conversion fails due to invalid slice ranges.