pub type SpanSlice<'a> = Span<&'a str>;
pub struct SpanSlice<'a> {Show 15 fields pub service: &'a str, pub name: &'a str, pub resource: &'a str, pub type: &'a str, pub trace_id: u128, pub span_id: u64, pub parent_id: u64, pub start: i64, pub duration: i64, pub error: i32, pub meta: HashMap<&'a str, &'a str>, pub metrics: HashMap<&'a str, f64>, pub meta_struct: HashMap<&'a str, Bytes>, pub span_links: Vec<SpanLink<&'a str>>, pub span_events: Vec<SpanEvent<&'a str>>, }
service: &'a str
name: &'a str
resource: &'a str
type: &'a str
trace_id: u128
span_id: u64
parent_id: u64
start: i64
duration: i64
error: i32
meta: HashMap<&'a str, &'a str>
metrics: HashMap<&'a str, f64>
meta_struct: HashMap<&'a str, Bytes>
span_links: Vec<SpanLink<&'a str>>
span_events: Vec<SpanEvent<&'a str>>
Converts a borrowed SpanSlice into an owned SpanBytes, by resolving all internal references into slices of the provided Bytes buffer. Returns None if any slice is out of bounds or invalid.
SpanSlice
SpanBytes
Bytes
None