Module v04

Module v04 

Structs

Span
The generic representation of a V04 span.
SpanEvent
The generic representation of a V04 span event. T is the type used to represent strings in the span event.
SpanLink
The generic representation of a V04 span link. T is the type used to represent strings in the span link.

Enums

AttributeAnyValue
AttributeArrayValue
SpanKey

Type Aliases

AttributeAnyValueBytes
AttributeAnyValueSlice
AttributeArrayValueBytes
AttributeArrayValueSlice
SpanBytes
SpanEventBytes
SpanEventSlice
SpanLinkBytes
SpanLinkSlice
SpanSlice
TraceChunksBytes