Span

Struct Span 

pub struct Span<T: TraceData> {
Show 15 fields pub service: T::Text, pub name: T::Text, pub resource: T::Text, pub type: T::Text, pub trace_id: u128, pub span_id: u64, pub parent_id: u64, pub start: i64, pub duration: i64, pub error: i32, pub meta: HashMap<T::Text, T::Text>, pub metrics: HashMap<T::Text, f64>, pub meta_struct: HashMap<T::Text, T::Bytes>, pub span_links: Vec<SpanLink<T>>, pub span_events: Vec<SpanEvent<T>>,
}
The generic representation of a V04 span.

T is the type used to represent strings in the span, it can be either owned (e.g. BytesString) or borrowed (e.g. &str). To define a generic function taking any Span<T> you can use the [SpanValue] trait:

use libdd_trace_utils::span::{v04::Span, TraceData};
fn foo<T: TraceData>(span: Span<T>) {
    let _ = span.meta.get("foo");
}

Fields

service: T::Textname: T::Textresource: T::Texttype: T::Texttrace_id: u128span_id: u64parent_id: u64start: i64duration: i64error: i32meta: HashMap<T::Text, T::Text>metrics: HashMap<T::Text, f64>meta_struct: HashMap<T::Text, T::Bytes>span_links: Vec<SpanLink<T>>span_events: Vec<SpanEvent<T>>