pub struct SharedDict<T> { /* private fields */ }Expand description
This struct represents the shared dictionary used for interning all the strings belonging to a v05 trace chunk.
Implementations
Sourcepub fn get_or_insert(&mut self, s: T) -> Result<u32, TryFromIntError>
pub fn get_or_insert(&mut self, s: T) -> Result<u32, TryFromIntError>
Gets the index of the interned string. If the string is not part of the dictionary it is added and its corresponding index returned.
Arguments:
str: string to look up in the dictionary.
pub fn len(&self) -> usize
pub fn iter(&self) -> impl Iterator<Item = &T>