pub struct Span {
pub service: u32,
pub name: u32,
pub resource: u32,
pub trace_id: u64,
pub span_id: u64,
pub parent_id: u64,
pub start: i64,
pub duration: i64,
pub error: i32,
pub meta: HashMap<u32, u32>,
pub metrics: HashMap<u32, f64>,
pub type: u32,
}Expand description
Structure that represent a TraceChunk Span which String fields are interned in a shared dictionary. The number of elements is fixed by the spec and they all need to be serialized, in case of adding more items the constant msgpack_decoder::v05::SPAN_ELEM_COUNT need to be updated.
Fields
service: u32name: u32resource: u32trace_id: u64span_id: u64parent_id: u64start: i64duration: i64error: i32meta: HashMap<u32, u32>metrics: HashMap<u32, f64>type: u32Trait Implementations
impl StructuralPartialEq for Span