Re-exports
pub use crate::send_data::send_data_result::SendDataResult;pub use crate::send_data::SendData;pub use crate::tracer_header_tags::TracerHeaderTags;
Structs
- Mini
Agent Metadata - Root
Span Tags - Tags gathered from a trace’s root span
Enums
Constants
- MAX_
PAYLOAD_ SIZE - The maximum payload size for a single request that can be sent to the trace agent. Payloads
larger than this size will be dropped and the agent will return a 413 error if
datadog-send-real-http-statusis set.
Functions
- coalesce_
send_ data - collect_
pb_ trace_ chunks - collect_
trace_ chunks - compute_
top_ level_ span - Updates all the spans top-level attribute. A span is considered top-level if:
- enrich_
span_ with_ azure_ function_ metadata - enrich_
span_ with_ google_ cloud_ function_ metadata - enrich_
span_ with_ mini_ agent_ metadata - get_
root_ span_ index - get_
traces_ from_ request_ body - First value of returned tuple is the payload size
- get_
v05_ traces_ from_ request_ body - has_
top_ level - Return true if the span has a top level key set
- is_
measured - Returns true if a span should be measured (i.e., it should get trace metrics calculated).
- is_
partial_ snapshot - Returns true if the span is a partial snapshot. This kind of spans are partial images of long-running spans. When incomplete, a partial snapshot has a metric _dd.partial_version which is a positive integer. The metric usually increases each time a new version of the same span is sent by the tracer
- set_
serverless_ root_ span_ tags