Module tracer_payload

Module tracer_payload 

Structs

DefaultTraceChunkProcessor
Default implementation of TraceChunkProcessor that does nothing.

Enums

TraceChunks
TraceEncoding
Enumerates the different encoding types.
TracerPayloadCollection
Enum representing a general abstraction for a collection of tracer payloads.

Traits

TraceChunkProcessor
A trait defining custom processing to be applied to TraceChunks.

Functions

decode_to_trace_chunks
This method processes the msgpack data contained within data based on the specified encoding_type, converting it into a collection of tracer payloads.

Type Aliases

TracerPayloadV04
TracerPayloadV05