Module buffer

Module buffer 

Structs

Buffer
Internal Buffer used to wrap msgpack data for decoding. Provides a couple accessors to extract data from the buffer.

Functions

read_string_ref_nomut
Read a string from buf.