Functions
- handle_
null_ marker - Handle the null value by peeking if the next value is a null marker, and will only advance the buffer if it is null. If it is not null, you can continue to decode as expected.
- read_
nullable_ str_ map_ to_ strings - Read a nullable vec of (string, string) pairs from the slices
buf. - read_
nullable_ string - Read a nullable string from the slices
buf. - read_
str_ map_ to_ hashmap - Read a hashmap of (string, string) from the slices
buf. Used for SpanLink/SpanEvent attributes which remain as HashMap. - read_
str_ map_ to_ vecmap - Read a VecMap of
(String, String)pairs from the slicesbuf.