pub fn handle_null_marker(buf: &mut &[u8]) -> boolExpand description
Handle the null value by peeking if the next value is a null marker, and will only advance the buffer if it is null. If it is not null, you can continue to decode as expected.
Returns
A boolean indicating whether the next value is null or not.