read_str_map_to_strings

Function read_str_map_to_strings 

pub fn read_str_map_to_strings<'a>(
    buf: &mut &'a [u8],
) -> Result<HashMap<&'a str, &'a str>, DecodeError>
Read a hashmap of (string, string) from the slices buf.

Errors

Fails if the buffer does not contain a valid map length prefix, or if any key or value is not a valid utf8 msgpack string.