pub fn from_slice(
data: &[u8],
) -> Result<(TracerPayloadSlice<'_>, usize), DecodeError>Expand description
Decodes a V1 msgpack payload from a borrowed slice into a TracerPayloadSlice.
The resulting payload borrows from the input buffer (same lifetime).