Functions
- to_len
- Computes the number of bytes required to encode the given traces.
- to_vec
- Serializes traces into a vector of bytes with a default capacity of 0.
- to_
vec_ with_ capacity - Serializes traces into a vector of bytes with specified capacity.
- write_
to_ slice - Encodes a collection of traces into a slice of bytes.