Functions
- to_
encoded_ byte_ len_ from_ v04 - Returns the number of bytes the V1 payload for
traceswould occupy. - to_
encoded_ byte_ len_ from_ v1 - Computes the number of bytes required to encode the given
TracerPayload. - to_
vec_ from_ v04 - Serializes traces into a
Vec<u8>using the V1 msgpack format. - to_
vec_ from_ v1 - Serializes a
TracerPayloadinto a vector of bytes with a default capacity of 0. - to_
vec_ with_ capacity_ from_ v04 - Serializes traces into a
Vec<u8>with a pre-allocated capacity. - to_
vec_ with_ capacity_ from_ v1 - Serializes a
TracerPayloadinto a vector of bytes with specified capacity. - write_
to_ slice_ from_ v04 - Serializes traces into a slice using the V1 msgpack format.
- write_
to_ slice_ from_ v1 - Encodes a
TracerPayloadinto a slice of bytes.