Functions
- to_
encoded_ byte_ len - Returns the number of bytes the V1 payload for
traceswould occupy. - to_
encoded_ byte_ len_ from_ payload_ v1 - Computes the number of bytes required to encode the given
TracerPayload. - to_vec
- Serializes traces into a
Vec<u8>using the V1 msgpack format. - to_
vec_ from_ payload_ v1 - Serializes a
TracerPayloadinto a vector of bytes with a default capacity of 0. - to_
vec_ from_ payload_ with_ capacity_ v1 - Serializes a
TracerPayloadinto a vector of bytes with specified capacity. - to_
vec_ with_ capacity - Serializes traces into a
Vec<u8>with a pre-allocated capacity. - write_
payload_ to_ slice_ v1 - Encodes a
TracerPayloadinto a slice of bytes. - write_
to_ slice - Serializes traces into a slice using the V1 msgpack format.