SendData

Struct SendData 

pub struct SendData { /* private fields */ }
SendData is a structure that holds the data to be sent to a target endpoint. It includes the payloads to be sent, the size of the data, the target endpoint, headers for the request, and a retry strategy for sending the data.

Example

use libdd_trace_protobuf::pb::TracerPayload;
use libdd_trace_utils::send_data::{
    SendData,
};
use libdd_common::Endpoint;
use libdd_common::http_common::new_default_client;
use libdd_trace_utils::send_with_retry::{RetryBackoffType, RetryStrategy};
use libdd_trace_utils::trace_utils::TracerHeaderTags;
use libdd_trace_utils::tracer_payload::TracerPayloadCollection;

#[cfg_attr(miri, ignore)]
async fn update_send_results_example() {
    let size = 100;
    let tracer_payload = TracerPayloadCollection::V07(
        vec![TracerPayload::default()]); // Replace with actual payload
    let tracer_header_tags = TracerHeaderTags::default(); // Replace with actual header tags
    let target = Endpoint::default(); // Replace with actual endpoint

    let mut send_data = SendData::new(size, tracer_payload, tracer_header_tags, &target);

    // Set a custom retry strategy
    let retry_strategy = RetryStrategy::new(3, 10, RetryBackoffType::Exponential, Some(5));

    send_data.set_retry_strategy(retry_strategy);

    let client = new_default_client();
    // Send the data
    let result = send_data.send(&client).await;
}

Implementations

Source

impl SendData

pub fn new( size: usize, tracer_payload: TracerPayloadCollection, tracer_header_tags: TracerHeaderTags<'_>, target: &Endpoint, ) -> SendData

Creates a new instance of SendData.

Arguments
  • size: Approximate size of the data to be sent in bytes.
  • tracer_payload: The payload to be sent.
  • tracer_header_tags: The header tags for the tracer.
  • target: The endpoint to which the data will be sent.
Returns

A new SendData instance.

pub fn len(&self) -> usize

Returns the user defined approximate size of the data to be sent in bytes.

Returns

The size of the data.

pub fn is_empty(&self) -> bool

Checks if the user defined approximate size of the data to be sent is zero.

Returns

true if size is 0, false otherwise.

pub fn get_target(&self) -> &Endpoint

Returns the target endpoint.

Returns

A reference to the target endpoint.

pub fn get_payloads(&self) -> &TracerPayloadCollection

Returns the payloads to be sent.

Returns

A reference to the vector of payloads.

pub fn set_retry_strategy(&mut self, retry_strategy: RetryStrategy)

Overrides the default RetryStrategy with user-defined values.

Arguments
  • retry_strategy: The new retry strategy to be used.
pub async fn send<C: Connect>( &self, http_client: &GenericHttpClient<C>, ) -> SendDataResult

Sends the data to the target endpoint.

Returns

A SendDataResult instance containing the result of the operation.