Module span

Module span 

Modules

trace_utils
Trace-utils functionalities implementation for tinybytes based spans
v04
v05

Structs

BytesData
TraceData implementation using Bytes and BytesString.
SliceData
TraceData implementation using &str and &[u8].
SpanKeyParseError

Traits

DeserializableTraceData
SpanBytes
SpanText
Trait representing the requirements for a type to be used as a Span “string” type. Note: Borrow is not required by the derived traits, but allows to access HashMap elements from a static str and check if the string is empty.
TraceData
Trait representing a tuple of (Text, Bytes) types used for different underlying data structures. Note: The functions are internal to the msgpack decoder and should not be used directly: they’re only exposed here due to the unavailability of min_specialization in stable Rust. Also note that the Clone and PartialEq bounds are only present for tests.

Type Aliases

SharedDictBytes