Module span

Module span 

Modules

trace_utils
Trace-utils functionalities implementation for tinybytes based spans
v05

Structs

Span
The generic representation of a V04 span.
SpanEvent
The generic representation of a V04 span event. T is the type used to represent strings in the span event.
SpanKeyParseError
SpanLink
The generic representation of a V04 span link. T is the type used to represent strings in the span link.

Enums

AttributeAnyValue
AttributeArrayValue
SpanKey

Traits

SpanText
Trait representing the requirements for a type to be used as a Span “string” type. Note: Borrow is not required by the derived traits, but allows to access HashMap elements from a static str and check if the string is empty.

Type Aliases

AttributeAnyValueBytes
AttributeAnyValueSlice
AttributeArrayValueBytes
AttributeArrayValueSlice
SharedDictBytes
SpanBytes
SpanEventBytes
SpanEventSlice
SpanLinkBytes
SpanLinkSlice
SpanSlice
TraceChunksBytes