Modules
- trace_
utils - Trace-utils functionalities implementation for tinybytes based spans
- v05
Structs
- Span
- The generic representation of a V04 span.
- Span
Event - The generic representation of a V04 span event.
Tis the type used to represent strings in the span event. - Span
KeyParse Error - Span
Link - The generic representation of a V04 span link.
Tis the type used to represent strings in the span link.
Enums
Traits
- Span
Text - Trait representing the requirements for a type to be used as a Span “string” type.
Note: Borrow
is not required by the derived traits, but allows to access HashMap elements from a static str and check if the string is empty.