Trace-utils functionalities implementation for tinybytes based spans
Structs
Functions
- compute_
top_ level_ span - Updates all the spans top-level attribute. A span is considered top-level if:
- drop_
chunks - Remove spans and chunks from a TraceCollection only keeping the ones that may be sampled by the agent.
- has_
top_ level - Return true if the span has a top level key set
- is_
measured - Returns true if a span should be measured (i.e., it should get trace metrics calculated).
- is_
partial_ snapshot - Returns true if the span is a partial snapshot. This kind of spans are partial images of long-running spans. When incomplete, a partial snapshot has a metric _dd.partial_version which is a positive integer. The metric usually increases each time a new version of the same span is sent by the tracer