pub fn drop_chunks<T>(traces: &mut Vec<Vec<Span<T>>>) -> DroppedP0Statswhere
T: SpanText,Expand description
Remove spans and chunks from a TraceCollection only keeping the ones that may be sampled by the agent.
Returns
A tuple containing the dropped p0 stats, the first value correspond the amount of traces dropped and the latter to the spans dropped.
Trace-level attributes
Some attributes related to the whole trace are stored in the root span of the chunk.