Module trace_utils_v1

Module trace_utils_v1 

Trace-utils functionalities implementation for V1 spans.

Functions

compute_top_level_span
Updates all the spans top-level attribute. A span is considered top-level if:
drop_chunks
Remove spans and chunks, only keeping the ones that may be sampled by the agent.
get_root_span_index
Returns the index of the root span in trace.
has_top_level
Returns true if the span has a top level key set
is_measured
Returns true if a span should be measured (i.e., it should get trace metrics calculated).
is_partial_snapshot
Returns true if the span is a partial snapshot. This kind of spans are partial images of long-running spans. When incomplete, a partial snapshot has an attribute _dd.partial_version which is a positive integer. This value usually increases each time a new version of the same span is sent by the tracer