Structs
- Span
- The generic representation of a V04 span.
- Span
Event - The generic representation of a V04 span event.
Tis the type used to represent strings in the span event. - Span
Link - The generic representation of a V04 span link.
Tis the type used to represent strings in the span link.