Modules
Structs
- Span
- Structure that represent a TraceChunk Span which String fields are interned in a shared dictionary. The number of elements is fixed by the spec and they all need to be serialized, in case of adding more items the constant msgpack_decoder::v05::SPAN_ELEM_COUNT need to be updated.
Functions
- from_
v04_ span - Converts a v0.4
Spaninto its v0.5 dictionary-encoded form.