is_partial_snapshot

Function is_partial_snapshot 

pub fn is_partial_snapshot(span: &Span) -> bool
Returns true if the span is a partial snapshot. This kind of spans are partial images of long-running spans. When incomplete, a partial snapshot has a metric _dd.partial_version which is a positive integer. The metric usually increases each time a new version of the same span is sent by the tracer