Structs
- Default
Trace Chunk Processor - Default implementation of
TraceChunkProcessorthat does nothing.
Enums
- Trace
Chunks - Trace
Encoding - Enumerates the different encoding types.
- Tracer
Payload Collection - Enum representing a general abstraction for a collection of tracer payloads.
Traits
- Trace
Chunk Processor - A trait defining custom processing to be applied to
TraceChunks.
Functions
- decode_
to_ trace_ chunks - This method processes the msgpack data contained within
databased on the specifiedencoding_type, converting it into a collection of tracer payloads.