TracerPayloadCollection

Enum TracerPayloadCollection 

pub enum TracerPayloadCollection {
    V07(Vec<TracerPayload>),
    V04(Vec<Vec<SpanBytes>>),
    V05((SharedDictBytes, Vec<Vec<Span>>)),
}
Enum representing a general abstraction for a collection of tracer payloads.

Variants



V07(Vec<TracerPayload>)

Collection of TracerPayloads.



V04(Vec<Vec<SpanBytes>>)

Collection of TraceChunkSpan.



V05((SharedDictBytes, Vec<Vec<Span>>))

Collection of TraceChunkSpan with de-duplicated strings.

Implementations

Source

impl TracerPayloadCollection

pub fn append(&mut self, other: &mut Self)

Appends other collection of the same type to the current collection.

#Arguments

  • other: collection of the same type.
Examples:
use libdd_trace_protobuf::pb::TracerPayload;
use libdd_trace_utils::tracer_payload::TracerPayloadCollection;
let mut col1 = TracerPayloadCollection::V07(vec![TracerPayload::default()]);
let mut col2 = TracerPayloadCollection::V07(vec![TracerPayload::default()]);
col1.append(&mut col2);
pub fn merge(&mut self)

Merges traces that came from the same origin together to reduce the payload size.

Examples:
use libdd_trace_protobuf::pb::TracerPayload;
use libdd_trace_utils::tracer_payload::TracerPayloadCollection;
let mut col1 =
    TracerPayloadCollection::V07(vec![TracerPayload::default(), TracerPayload::default()]);
col1.merge();
pub fn size(&self) -> usize

Computes the size of the collection.

Returns

The number of traces contained in the collection.

Examples:
use libdd_trace_protobuf::pb::TracerPayload;
use libdd_trace_utils::tracer_payload::TracerPayloadCollection;
let col1 = TracerPayloadCollection::V07(vec![TracerPayload::default()]);
col1.size();